Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(24)

Unified Diff: chrome/browser/ui/webui/signin/login_ui_test_utils.h

Issue 1473543002: Implement newly designed sign-in related histograms for desktop platorms. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: format Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/signin/login_ui_test_utils.h
diff --git a/chrome/browser/ui/webui/signin/login_ui_test_utils.h b/chrome/browser/ui/webui/signin/login_ui_test_utils.h
index acddd3934aeb888109aae6ad4c13d116a4c5993c..9fdc68910023410fa3554f7c5ddb8095c3068827 100644
--- a/chrome/browser/ui/webui/signin/login_ui_test_utils.h
+++ b/chrome/browser/ui/webui/signin/login_ui_test_utils.h
@@ -45,12 +45,12 @@ void SigninInOldGaiaFlow(Browser* browser,
// This will block until a signin succeeded or failed notification is observed.
// In case |wait_for_account_cookies|, the call will block until the account
// cookies have been written to the cookie jar.
// |signin_source| identifies the source used to load the signin page.
bool SignInWithUI(Browser* browser,
const std::string& email,
const std::string& password,
bool wait_for_account_cookies,
- signin_metrics::Source signin_source);
+ signin_metrics::AccessPoint access_point);
// Most common way to sign in a user, it does not wait for cookies to be set
// and uses the SOURCE_START_PAGE as signin source.
« no previous file with comments | « chrome/browser/ui/webui/signin/login_ui_service.cc ('k') | chrome/browser/ui/webui/signin/login_ui_test_utils.cc » ('j') | no next file with comments »
@@ -45,12 +45,12 @@ void SigninInOldGaiaFlow(Browser* browser,
// In case |wait_for_account_cookies|, the call will block until the account
// cookies have been written to the cookie jar.
-// |signin_source| identifies the source used to load the signin page.
+// |access_point| identifies the access point used to load the signin page.
bool SignInWithUI(Browser* browser,
const std::string& email,

Powered by Google App Engine
This is Rietveld 408576698